@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Author: Óscar Nájera
 # License: 3-clause BSD
 """
@@ -23,6 +22,8 @@ from sphinx.errors import ExtensionError
 from sphinx.search import js_index
 import sphinx.util
 
+from .utils import status_iterator
+
 
 logger = sphinx.util.logging.getLogger('sphinx-gallery')
 
@@ -39,7 +40,7 @@ def _get_data(url):
         if encoding == 'gzip':
             data = gzip.GzipFile(fileobj=BytesIO(data)).read()
         elif encoding != 'plain':
-            raise ExtensionError('unknown encoding %r' % (encoding,))
+            raise ExtensionError(f'unknown encoding {encoding!r}')
         data = data.decode('utf-8')
     else:
         with codecs.open(url, mode='r', encoding='utf-8') as fid:
@@ -123,7 +124,7 @@ def parse_sphinx_docopts(index):
     return docopts
 
 
-class SphinxDocLinkResolver(object):
+class SphinxDocLinkResolver:
     """ Resolve documentation links using searchindex.js generated by Sphinx
 
     Parameters
@@ -299,10 +300,10 @@ class SphinxDocLinkResolver(object):
 
 def _handle_http_url_error(e, msg='fetching'):
     if isinstance(e, HTTPError):
-        error_msg = '%s %s: %s (%s)' % (msg, e.url, e.code, e.msg)
+        error_msg = f'{msg} {e.url}: {e.code} ({e.msg})'
     elif isinstance(e, URLError):
-        error_msg = '%s: %s' % (msg, e.reason)
-    logger.warning('The following %s has occurred %s' % (
+        error_msg = f'{msg}: {e.reason}'
+    logger.warning('The following {} has occurred {}'.format(
         type(e).__name__, error_msg))
 
 
@@ -344,7 +345,7 @@ def _embed_code_links(app, gallery_conf, gallery_dir):
     flat = [[dirpath, filename]
             for dirpath, _, filenames in os.walk(html_gallery_dir)
             for filename in filenames]
-    iterator = sphinx.util.status_iterator(
+    iterator = status_iterator(
         flat, 'embedding documentation hyperlinks for %s... ' % gallery_dir,
         color='fuchsia', length=len(flat),
         stringify_func=lambda x: os.path.basename(x[1]))
@@ -381,7 +382,7 @@ def _embed_code_links(app, gallery_conf, gallery_dir):
                                 cobj, full_fname, return_type=True)
                         except (HTTPError, URLError) as e:
                             _handle_http_url_error(
-                                e, msg='resolving %s.%s' % (modname, cname))
+                                e, msg=f'resolving {modname}.{cname}')
 
                     # next try intersphinx
                     if this_module == modname == 'builtins':
@@ -393,7 +394,7 @@ def _embed_code_links(app, gallery_conf, gallery_dir):
                         if modname == 'builtins':
                             want = cname
                         else:
-                            want = '%s.%s' % (modname, cname)
+                            want = f'{modname}.{cname}'
                         for key, value in inv.items():
                             # only python domain
                             if key.startswith('py') and want in value:
@@ -410,7 +411,7 @@ def _embed_code_links(app, gallery_conf, gallery_dir):
                         # Add CSS classes
                         name_html = period.join(orig_pattern % part
                                                 for part in name.split('.'))
-                        full_function_name = '%s.%s' % (modname, cname)
+                        full_function_name = f'{modname}.{cname}'
                         css_class = ("sphx-glr-backref-module-" +
                                      _sanitize_css_class(modname))
                         if type_ is not None:
