@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Author: Óscar Nájera
 # License: 3-clause BSD
 """
@@ -10,7 +9,6 @@ when building the documentation.
 """
 
 
-from __future__ import division, print_function, absolute_import
 import codecs
 import copy
 from datetime import timedelta, datetime
@@ -29,8 +27,7 @@ from .utils import _replace_md5, _has_optipng, _has_pypandoc, _has_graphviz
 from .backreferences import _finalize_backreferences
 from .gen_rst import (generate_dir_rst, SPHX_GLR_SIG, _get_memory_base,
                       _get_readme)
-from .scrapers import (
-    _scraper_dict, _reset_dict, _import_matplotlib, _MAYAVI_WARN)
+from .scrapers import _scraper_dict, _reset_dict, _import_matplotlib
 from .docs_resolv import embed_code_links
 from .downloads import generate_zipfiles
 from .sorting import NumberOfCodeLinesSortKey
@@ -91,7 +88,7 @@ DEFAULT_GALLERY_CONF = {
     'compress_images': (),
     'reset_modules': ('matplotlib', 'seaborn'),
     'reset_modules_order': 'before',
-    'first_notebook_cell': '%matplotlib inline',
+    'first_notebook_cell': None,
     'last_notebook_cell': None,
     'notebook_images': False,
     'pypandoc': False,
@@ -125,26 +122,8 @@ def _bool_eval(x):
     return bool(x)
 
 
-def parse_config(app, check_keys=True):
-    """Process the Sphinx Gallery configuration."""
-    plot_gallery = _bool_eval(app.builder.config.plot_gallery)
-    src_dir = app.builder.srcdir
-    abort_on_example_error = _bool_eval(
-        app.builder.config.abort_on_example_error)
-    lang = app.builder.config.highlight_language
-    gallery_conf = _complete_gallery_conf(
-        app.config.sphinx_gallery_conf, src_dir, plot_gallery,
-        abort_on_example_error, lang, app.builder.name, app,
-        check_keys)
-
-    # this assures I can call the config in other places
-    app.config.sphinx_gallery_conf = gallery_conf
-    app.config.html_static_path.append(glr_path_static())
-    return gallery_conf
-
-
-def _update_gallery_conf(gallery_conf):
-    """Update gallery config.
+def _update_gallery_conf_exclude_implicit_doc(gallery_conf):
+    """Update gallery config exclude_implicit_doc.
 
     This is separate function for better testability.
     """
@@ -154,45 +133,40 @@ def _update_gallery_conf(gallery_conf):
     gallery_conf['exclude_implicit_doc_regex'] = exclude_regex
 
 
-def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
-                           abort_on_example_error, lang='python',
-                           builder_name='html', app=None, check_keys=True):
+def _update_gallery_conf_builder_inited(
+        sphinx_gallery_conf, src_dir, plot_gallery=True,
+        abort_on_example_error=False, lang='python',
+        builder_name='html'):
+    sphinx_gallery_conf.update(plot_gallery=plot_gallery)
+    sphinx_gallery_conf.update(abort_on_example_error=abort_on_example_error)
+    sphinx_gallery_conf['src_dir'] = src_dir
+    lang = lang if lang in ('python', 'python3', 'default') else 'python'
+    sphinx_gallery_conf['lang'] = lang
+    # Make it easy to know which builder we're in
+    sphinx_gallery_conf['builder_name'] = builder_name
+
+
+def _fill_gallery_conf_defaults(sphinx_gallery_conf, app=None,
+                                check_keys=True):
     gallery_conf = copy.deepcopy(DEFAULT_GALLERY_CONF)
     options = sorted(gallery_conf)
-    # sphinx-autoapi can run before our config filling can occur, which
-    # when used with show_api_usage=True can cause us to add this early.
-    # In theory we could bump our priority above theirs, but this could have
-    # unintented consequences.
-    ignore_keys = ('_sg_api_entries',)
-    extra_keys = sorted(
-        (set(sphinx_gallery_conf) - set(options)) - set(ignore_keys)
-    )
+    extra_keys = sorted(set(sphinx_gallery_conf) - set(options))
     if extra_keys and check_keys:
         msg = 'Unknown key(s) in sphinx_gallery_conf:\n'
         for key in extra_keys:
             options = get_close_matches(key, options, cutoff=0.66)
             msg += repr(key)
             if len(options) == 1:
-                msg += ', did you mean %r?' % (options[0],)
+                msg += f', did you mean {options[0]!r}?'
             elif len(options) > 1:
-                msg += ', did you mean one of %r?' % (options,)
+                msg += f', did you mean one of {options!r}?'
             msg += '\n'
         raise ConfigError(msg.strip())
     gallery_conf.update(sphinx_gallery_conf)
-    if sphinx_gallery_conf.get('find_mayavi_figures', False):
-        logger.warning(
-            "Deprecated image scraping variable `find_mayavi_figures`\n"
-            "detected, use `image_scrapers` instead as:\n\n"
-            "   image_scrapers=('matplotlib', 'mayavi')",
-            type=DeprecationWarning)
-        gallery_conf['image_scrapers'] += ('mayavi',)
-    gallery_conf.update(plot_gallery=plot_gallery)
-    gallery_conf.update(abort_on_example_error=abort_on_example_error)
     # XXX anything that can only be a bool (rather than str) should probably be
     # evaluated this way as it allows setting via -D on the command line
     for key in ('promote_jupyter_magic', 'run_stale_examples',):
         gallery_conf[key] = _bool_eval(gallery_conf[key])
-    gallery_conf['src_dir'] = src_dir
     gallery_conf['app'] = app
 
     # Check capture_repr
@@ -248,8 +222,6 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
     for si, scraper in enumerate(scrapers):
         if isinstance(scraper, str):
             if scraper in _scraper_dict:
-                if scraper == 'mayavi':
-                    logger.warning(_MAYAVI_WARN)
                 scraper = _scraper_dict[scraper]
             else:
                 orig_scraper = scraper
@@ -262,7 +234,7 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
                                       % (orig_scraper, exp))
             scrapers[si] = scraper
         if not callable(scraper):
-            raise ConfigError('Scraper %r was not callable' % (scraper,))
+            raise ConfigError(f'Scraper {scraper!r} was not callable')
     gallery_conf['image_scrapers'] = tuple(scrapers)
     del scrapers
     # Here we try to set up matplotlib but don't raise an error,
@@ -330,8 +302,6 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
                           "['before', 'after', 'both'], "
                           'got %r' % gallery_conf['reset_modules_order'])
 
-    lang = lang if lang in ('python', 'python3', 'default') else 'python'
-    gallery_conf['lang'] = lang
     del resetters
 
     # Ensure the first cell text is a string if we have it
@@ -369,8 +339,6 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
                                   "values: %s, got: %s."
                                   % (accepted_keys, key))
 
-    # Make it easy to know which builder we're in
-    gallery_conf['builder_name'] = builder_name
     gallery_conf['titles'] = {}
     # Ensure 'backreferences_dir' is str, pathlib.Path or None
     backref = gallery_conf['backreferences_dir']
@@ -388,7 +356,6 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
     gallery_conf['binder'] = check_binder_conf(gallery_conf['binder'])
 
     # jupyterlite
-    print('_complete_gallery_conf', gallery_conf.get('jupyterlite'))
     gallery_conf['jupyterlite'] = check_jupyterlite_conf(
         gallery_conf.get('jupyterlite', {}), app)
 
@@ -413,7 +380,7 @@ def _complete_gallery_conf(sphinx_gallery_conf, src_dir, plot_gallery,
             'gallery_conf["show_api_usage"] must be True, False or "unused", '
             'got %s' % gallery_conf['show_api_usage'])
 
-    _update_gallery_conf(gallery_conf)
+    _update_gallery_conf_exclude_implicit_doc(gallery_conf)
 
     return gallery_conf
 
@@ -515,7 +482,7 @@ def generate_gallery_rst(app):
     """
 
     logger.info('generating gallery...', color='white')
-    gallery_conf = parse_config(app)
+    gallery_conf = app.config.sphinx_gallery_conf
 
     seen_backrefs = set()
 
@@ -659,7 +626,7 @@ def generate_gallery_rst(app):
         lines, lens = _format_for_writing(
             costs, os.path.normpath(gallery_conf['src_dir']), kind='console')
         for name, t, m in lines:
-            text = ('    - %s:   ' % (name,)).ljust(lens[0] + 10)
+            text = (f'    - {name}:   ').ljust(lens[0] + 10)
             if t is None:
                 text += '(not run)'
                 logger.info(text)
@@ -692,7 +659,7 @@ def _sec_to_readable(t):
     # there aren't many > 99 minute scripts, but occasionally some
     # > 9 minute ones
     t = datetime(1, 1, 1) + timedelta(seconds=t)
-    t = '{0:02d}:{1:02d}.{2:03d}'.format(
+    t = '{:02d}:{:02d}.{:03d}'.format(
         t.hour * 60 + t.minute, t.second,
         int(round(t.microsecond / 1000.)))
     return t
@@ -714,8 +681,8 @@ def _format_for_writing(costs, path, kind='rst'):
         else:  # like in generate_gallery
             assert kind == 'console'
             name = os.path.relpath(cost[1], path)
-            t = '%0.2f sec' % (cost[0][0],)
-        m = '{0:.1f} MB'.format(cost[0][1])
+            t = f'{cost[0][0]:0.2f} sec'
+        m = f'{cost[0][1]:.1f} MB'
         lines.append([name, t, m])
     lens = [max(x) for x in zip(*[[len(item) for item in cost]
                                   for cost in lines])]
@@ -732,13 +699,13 @@ def write_computation_times(gallery_conf, target_dir, costs):
     with codecs.open(os.path.join(target_dir, 'sg_execution_times.rst'), 'w',
                      encoding='utf-8') as fid:
         fid.write(SPHX_GLR_COMP_TIMES.format(new_ref))
-        fid.write('**{0}** total execution time for **{1}** files:\n\n'
+        fid.write('**{}** total execution time for **{}** files:\n\n'
                   .format(_sec_to_readable(total_time), target_dir_clean))
         lines, lens = _format_for_writing(costs, target_dir_clean)
         del costs
         hline = ''.join(('+' + '-' * (length + 2)) for length in lens) + '+\n'
         fid.write(hline)
-        format_str = ''.join('| {%s} ' % (ii,)
+        format_str = ''.join(f'| {{{ii}}} '
                              for ii in range(len(lines[0]))) + '|\n'
         for line in lines:
             line = [ll.ljust(len_) for ll, len_ in zip(line, lens)]
@@ -749,9 +716,6 @@ def write_computation_times(gallery_conf, target_dir, costs):
 
 
 def write_api_entries(app, what, name, obj, options, lines):
-    # sphinx-autoapi can do this before we manage to complete our config
-    if 'show_api_usage' not in app.config.sphinx_gallery_conf:
-        app.config.sphinx_gallery_conf['show_api_usage'] = False
     if app.config.sphinx_gallery_conf['show_api_usage'] is False:
         return
     if '_sg_api_entries' not in app.config.sphinx_gallery_conf:
@@ -909,7 +873,7 @@ def write_api_entry_usage(app, docname, source):
             unused_api_entries.append(entry)
         else:
             used_api_entries[entry] = list()
-            with open(example_fname, 'r', encoding='utf-8') as fid2:
+            with open(example_fname, encoding='utf-8') as fid2:
                 for line in fid2:
                     if line.startswith('  :ref:'):
                         example_name = line.split('`')[1]
@@ -951,8 +915,7 @@ def write_api_entry_usage(app, docname, source):
             source[0] += '\n\n'
 
         if has_graphviz:
-            used_modules = set([entry.split('.')[0]
-                                for entry in used_api_entries])
+            used_modules = {entry.split('.')[0] for entry in used_api_entries}
             for module in sorted(used_modules):
                 source[0] += (
                     f'{module}\n' + '^' * len(module) + '\n\n'
@@ -1006,13 +969,13 @@ def write_junit_xml(gallery_conf, target_dir, costs):
             continue  # not subselected by our regex
         title = gallery_conf['titles'][fname]
         output += (
-            u'<testcase classname={0!s} file={1!s} line="1" '
-            u'name={2!s} time="{3!r}">'
+            '<testcase classname={!s} file={!s} line="1" '
+            'name={!s} time="{!r}">'
             .format(quoteattr(os.path.splitext(os.path.basename(fname))[0]),
                     quoteattr(os.path.relpath(fname, src_dir)),
                     quoteattr(title), t))
         if fname in failing_as_expected:
-            output += u'<skipped message="expected example failure"></skipped>'
+            output += '<skipped message="expected example failure"></skipped>'
             n_skips += 1
         elif fname in failing_unexpectedly or fname in passing_unexpectedly:
             if fname in failing_unexpectedly:
@@ -1020,16 +983,16 @@ def write_junit_xml(gallery_conf, target_dir, costs):
             else:  # fname in passing_unexpectedly
                 traceback = 'Passed even though it was marked to fail'
             n_failures += 1
-            output += (u'<failure message={0!s}>{1!s}</failure>'
+            output += ('<failure message={!s}>{!s}</failure>'
                        .format(quoteattr(traceback.splitlines()[-1].strip()),
                                escape(traceback)))
-        output += u'</testcase>'
+        output += '</testcase>'
         n_tests += 1
         elapsed += t
-    output += u'</testsuite>'
-    output = (u'<?xml version="1.0" encoding="utf-8"?>'
-              u'<testsuite errors="0" failures="{0}" name="sphinx-gallery" '
-              u'skipped="{1}" tests="{2}" time="{3}">'
+    output += '</testsuite>'
+    output = ('<?xml version="1.0" encoding="utf-8"?>'
+              '<testsuite errors="0" failures="{}" name="sphinx-gallery" '
+              'skipped="{}" tests="{}" time="{}">'
               .format(n_failures, n_skips, n_tests, elapsed)) + output
     # Actually write it
     fname = os.path.normpath(os.path.join(target_dir, gallery_conf['junit']))
@@ -1060,9 +1023,9 @@ def touch_empty_backreferences(app, what, name, obj, options, lines):
 
 
 def _expected_failing_examples(gallery_conf):
-    return set(
+    return {
         os.path.normpath(os.path.join(gallery_conf['src_dir'], path))
-        for path in gallery_conf['expected_failing_examples'])
+        for path in gallery_conf['expected_failing_examples']}
 
 
 def _parse_failures(gallery_conf):
@@ -1078,7 +1041,7 @@ def _parse_failures(gallery_conf):
     # filter from examples actually run
     passing_unexpectedly = [
         src_file for src_file in passing_unexpectedly
-        if re.search(gallery_conf.get('filename_pattern'), src_file)]
+        if re.search(gallery_conf['filename_pattern'], src_file)]
     return failing_as_expected, failing_unexpectedly, passing_unexpectedly
 
 
@@ -1200,12 +1163,46 @@ def get_default_config_value(key):
     return default_getter
 
 
+def fill_gallery_conf_defaults(app, config, check_keys=True):
+    """Check the sphinx-gallery config and set its defaults.
+
+    This is called early at config-inited, so that all the rest of the code can
+    do things like ``sphinx_gallery_conf['binder']['use_jupyter_lab']``, even
+    if the keys have not been set explicitly in conf.py.
+    """
+    new_sphinx_gallery_conf = _fill_gallery_conf_defaults(
+        config.sphinx_gallery_conf, app=app, check_keys=check_keys)
+    config.sphinx_gallery_conf = new_sphinx_gallery_conf
+    config.html_static_path.append(glr_path_static())
+
+
+def update_gallery_conf_builder_inited(app):
+    """Update the the sphinx-gallery config at builder-inited.
+    """
+    plot_gallery = _bool_eval(app.builder.config.plot_gallery)
+    src_dir = app.builder.srcdir
+    abort_on_example_error = _bool_eval(
+        app.builder.config.abort_on_example_error)
+    lang = app.builder.config.highlight_language
+    _update_gallery_conf_builder_inited(
+        app.config.sphinx_gallery_conf,
+        src_dir,
+        plot_gallery=plot_gallery,
+        abort_on_example_error=abort_on_example_error,
+        lang=lang,
+        builder_name=app.builder.name
+    )
+
+
 def setup(app):
     """Setup Sphinx-Gallery sphinx extension"""
     app.add_config_value('sphinx_gallery_conf', DEFAULT_GALLERY_CONF, 'html')
     for key in ['plot_gallery', 'abort_on_example_error']:
         app.add_config_value(key, get_default_config_value(key), 'html')
 
+    # Early filling of sphinx_gallery_conf defaults at config-inited
+    app.connect('config-inited', fill_gallery_conf_defaults,
+                priority=10)
     # set small priority value, so that pre_configure_jupyterlite_sphinx is
     # called before jupyterlite_sphinx config-inited
     app.connect(
@@ -1226,6 +1223,9 @@ def setup(app):
 
     imagesg_addnode(app)
 
+    # Early update of sphinx_gallery_conf at builder-inited
+    app.connect('builder-inited', update_gallery_conf_builder_inited,
+                priority=10)
     app.connect('builder-inited', generate_gallery_rst)
     app.connect('build-finished', copy_binder_files)
     app.connect('build-finished', create_jupyterlite_contents)
