@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Author: Óscar Nájera
 # License: 3-clause BSD
 """
@@ -7,7 +6,7 @@ Scrapers for embedding images
 
 Collect images that have been produced by code blocks.
 
-The only scrapers we support are Matplotlib and Mayavi, others should
+The only scraper we natively support is Matplotlib, others should
 live in modules that will support them (e.g., PyVista, Plotly).  Scraped
 images are injected as rst ``image-sg`` directives into the ``.rst``
 file generated for each example script.
@@ -20,13 +19,13 @@ import sys
 import re
 from textwrap import indent
 from pathlib import PurePosixPath
-from warnings import filterwarnings, warn
+from warnings import filterwarnings
 
 from sphinx.errors import ExtensionError
-from .utils import scale_image, optipng
+from .utils import optipng
 
 __all__ = ['save_figures', 'figure_rst', 'ImagePathIterator', 'clean_modules',
-           'matplotlib_scraper', 'mayavi_scraper']
+           'matplotlib_scraper']
 
 
 ###############################################################################
@@ -101,21 +100,24 @@ def matplotlib_scraper(block, block_vars, gallery_conf, **kwargs):
         Additional keyword arguments to pass to
         :meth:`~matplotlib.figure.Figure.savefig`, e.g. ``format='svg'``.
         The ``format`` kwarg in particular is used to set the file extension
-        of the output file (currently only 'png', 'jpg', and 'svg' are
-        supported).
+        of the output file (currently only 'png', 'jpg', 'svg', 'gif', and
+        'webp' are supported).
 
     Returns
     -------
     rst : str
-        The ReSTructuredText that will be rendered to HTML containing
+        The reStructuredText that will be rendered to HTML containing
         the images. This is often produced by :func:`figure_rst`.
     """
-    matplotlib, plt = _import_matplotlib()
+    # Do not use _import_matplotlib() to avoid potentially changing the backend
+    import matplotlib
+    import matplotlib.pyplot as plt
+
     from matplotlib.animation import Animation
     image_path_iterator = block_vars['image_path_iterator']
     image_rsts = []
     # Check for srcset hidpi images
-    srcset = gallery_conf.get('image_srcset', [])
+    srcset = gallery_conf['image_srcset']
     srcset_mult_facs = [1]  # one is always supplied...
     for st in srcset:
         if (len(st) > 0) and (st[-1] == 'x'):
@@ -131,7 +133,7 @@ def matplotlib_scraper(block, block_vars, gallery_conf, **kwargs):
 
     # Check for animations
     anims = list()
-    if gallery_conf.get('matplotlib_animations', False):
+    if gallery_conf['matplotlib_animations']:
         for ani in block_vars['example_globals'].values():
             if isinstance(ani, Animation):
                 anims.append(ani)
@@ -207,7 +209,7 @@ def matplotlib_scraper(block, block_vars, gallery_conf, **kwargs):
         image_rsts = [re.sub(r':class: sphx-glr-single-img',
                              ':class: sphx-glr-multi-img',
                              image) for image in image_rsts]
-        image_rsts = [HLIST_IMAGE_MATPLOTLIB + indent(image, u' ' * 6)
+        image_rsts = [HLIST_IMAGE_MATPLOTLIB + indent(image, ' ' * 6)
                       for image in image_rsts]
         rst = HLIST_HEADER + ''.join(image_rsts)
     return rst
@@ -237,71 +239,12 @@ def _anim_rst(anim, image_path, gallery_conf):
     return _ANIMATION_RST.format(html)
 
 
-def mayavi_scraper(block, block_vars, gallery_conf):
-    """Scrape Mayavi images.
-
-    .. warning::
-         mayavi_scraper is deprecated and will be removed in 0.13.0.
-         Use custom scraping code instead -- see the updated sphinx_gallery
-         documentation for details.
-
-    Parameters
-    ----------
-    block : tuple
-        A tuple containing the (label, content, line_number) of the block.
-    block_vars : dict
-        Dict of block variables.
-    gallery_conf : dict
-        Contains the configuration of Sphinx-Gallery
-
-    Returns
-    -------
-    rst : str
-        The ReSTructuredText that will be rendered to HTML containing
-        the images. This is often produced by :func:`figure_rst`.
-    """
-    warn(_MAYAVI_WARN, FutureWarning, stacklevel=2)
-    return _MayaviScraper()(block, block_vars, gallery_conf)
-
-
-_MAYAVI_WARN = (
-    'mayavi_scraper is deprecated and will be removed in 0.13.0. '
-    'Use custom scraping code instead -- see the updated sphinx_gallery '
-    'documentation for details.'
-)
-
-
-class _MayaviScraper():
-    def __repr__(self):
-        return 'MayaviScraper'
-
-    def __call__(self, block, block_vars, gallery_conf):
-        from mayavi import mlab
-        image_path_iterator = block_vars['image_path_iterator']
-        image_paths = list()
-        e = mlab.get_engine()
-        for scene, image_path in zip(e.scenes, image_path_iterator):
-            try:
-                mlab.savefig(image_path, figure=scene)
-            except Exception:
-                mlab.close(all=True)
-                raise
-            # make sure the image is not too large
-            scale_image(image_path, image_path, 850, 999)
-            if 'images' in gallery_conf['compress_images']:
-                optipng(image_path, gallery_conf['compress_images_args'])
-            image_paths.append(image_path)
-        mlab.close(all=True)
-        return figure_rst(image_paths, gallery_conf['src_dir'])
-
-
 _scraper_dict = dict(
     matplotlib=matplotlib_scraper,
-    mayavi=_MayaviScraper(),
 )
 
 
-class ImagePathIterator(object):
+class ImagePathIterator:
     """Iterate over image paths for a given example.
 
     Parameters
@@ -344,7 +287,7 @@ class ImagePathIterator(object):
         for ii in range(self._stop):
             yield self.next()
         else:
-            raise ExtensionError('Generated over %s images' % (self._stop,))
+            raise ExtensionError(f'Generated over {self._stop} images')
 
     def next(self):
         return self.__next__()
@@ -357,19 +300,20 @@ class ImagePathIterator(object):
 
 
 # For now, these are what we support
-_KNOWN_IMG_EXTS = ('png', 'svg', 'jpg', 'gif')
+# Update advanced.rst if this list is changed
+_KNOWN_IMG_EXTS = ('png', 'svg', 'jpg', 'gif', 'webp')
 
 
 def _find_image_ext(path):
     """Find an image, tolerant of different file extensions."""
     path = os.path.splitext(path)[0]
     for ext in _KNOWN_IMG_EXTS:
-        this_path = '%s.%s' % (path, ext)
+        this_path = f'{path}.{ext}'
         if os.path.isfile(this_path):
             break
     else:
         ext = 'png'
-    return ('%s.%s' % (path, ext), ext)
+    return (f'{path}.{ext}', ext)
 
 
 def save_figures(block, block_vars, gallery_conf):
@@ -390,7 +334,7 @@ def save_figures(block, block_vars, gallery_conf):
         rst code to embed the images in the document.
     """
     image_path_iterator = block_vars['image_path_iterator']
-    all_rst = u''
+    all_rst = ''
     prev_count = len(image_path_iterator)
     for scraper in gallery_conf['image_scrapers']:
         rst = scraper(block, block_vars, gallery_conf)
@@ -411,7 +355,7 @@ def save_figures(block, block_vars, gallery_conf):
 
 
 def figure_rst(figure_list, sources_dir, fig_titles='', srcsetpaths=None):
-    """Generate RST for a list of image filenames.
+    """Generate reST for a list of image filenames.
 
     Depending on whether we have one or more figures, we use a
     single rst call to 'image' or a horizontal list.
