@@ -1,31 +1,29 @@
-# -*- coding: utf-8 -*-
 # Author: Óscar Nájera
 # License: 3-clause BSD
 """
 Testing the rst files generator
 """
-from __future__ import division, absolute_import, print_function
 import os
 import tempfile
 import sys
 
 import pytest
 
+from sphinx.errors import ExtensionError
 import sphinx_gallery.docs_resolv as sg
-from sphinx_gallery.utils import _TempDir
 
 
 def test_embed_code_links_get_data():
     """Test that we can get data for code links."""
-    sg._get_data('http://docs.scipy.org/doc/scipy/reference')
+    sg._get_data('https://numpy.org/doc/1.18/reference')
     sg._get_data('http://scikit-learn.org/stable/')  # GZip
 
 
-def test_shelve():
+def test_shelve(tmpdir):
     """Test if shelve can be caches information
     retrieved after file is deleted"""
     test_string = 'test information'
-    tmp_cache = _TempDir()
+    tmp_cache = str(tmpdir)
     with tempfile.NamedTemporaryFile('w', delete=False) as f:
         f.write(test_string)
     try:
@@ -41,8 +39,7 @@ def test_shelve():
 
     # shelve keys need to be str in python 2, deal with unicode input
     if sys.version_info[0] == 2:
-        unicode_name = unicode(f.name)
-        assert sg.get_data(unicode_name, tmp_cache) == test_string
+        assert sg.get_data(f.name, tmp_cache) == test_string
 
 
 def test_parse_sphinx_docopts():
@@ -88,11 +85,11 @@ def test_parse_sphinx_docopts():
         'SOURCELINK_SUFFIX': '.txt'
     }
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ExtensionError):
         sg.parse_sphinx_docopts('empty input')
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ExtensionError):
         sg.parse_sphinx_docopts('DOCUMENTATION_OPTIONS = ')
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ExtensionError):
         sg.parse_sphinx_docopts('DOCUMENTATION_OPTIONS = {')
