@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 # Author: Óscar Nájera
 # License: 3-clause BSD
 """
 Test the SG pipeline used with Sphinx
 """
-from __future__ import division, absolute_import, print_function
 
 import codecs
 from io import StringIO
@@ -14,6 +12,8 @@ import re
 import shutil
 import sys
 import time
+import glob
+import json
 
 from packaging.version import Version
 
@@ -30,7 +30,7 @@ import pytest
 
 # total number of plot_*.py files in tinybuild/examples + examples_rst_index
 # + examples_with_rst
-N_EXAMPLES = 13 + 3 + 2
+N_EXAMPLES = 15 + 3 + 2
 N_FAILING = 2
 N_GOOD = N_EXAMPLES - N_FAILING  # galleries that run w/o error
 # passthroughs examples_rst_index, examples_with_rst
@@ -43,7 +43,7 @@ N_EXECUTE = 2 + 3 + 1
 # gen_modules + sg_api_usage + doc/index.rst + minigallery.rst
 N_OTHER = 9 + 1 + 1 + 1 + 1
 N_RST = N_EXAMPLES + N_PASS + N_INDEX + N_EXECUTE + N_OTHER
-N_RST = '(%s|%s|%s)' % (N_RST, N_RST - 1, N_RST - 2)  # AppVeyor weirdness
+N_RST = f'({N_RST}|{N_RST - 1}|{N_RST - 2})'  # AppVeyor weirdness
 
 
 @pytest.fixture(scope='module')
@@ -96,7 +96,7 @@ def test_timings(sphinx_app):
     with codecs.open(timings_rst, 'r', 'utf-8') as fid:
         content = fid.read()
     assert ':ref:`sphx_glr_auto_examples_plot_numpy_matplotlib.py`' in content
-    parenthetical = '(``%s``)' % ('plot_numpy_matplotlib.py',)
+    parenthetical = '(``{}``)'.format('plot_numpy_matplotlib.py')
     assert parenthetical in content
     # HTML output
     timings_html = op.join(out_dir, 'auto_examples',
@@ -198,7 +198,7 @@ def test_junit(sphinx_app, tmpdir):
         contents = fid.read()
     assert 'errors="0" failures="2"' in contents
     # this time we only ran the stale files
-    assert 'tests="%s"' % (N_FAILING + 1,) in contents
+    assert f'tests="{N_FAILING + 1}"' in contents
     assert '<failure message="RuntimeError: Forcing' in contents
     assert 'Passed even though it was marked to fail' in contents
 
@@ -289,18 +289,20 @@ def test_image_formats(sphinx_app):
     thumb_fnames = ['../_images/sphx_glr_plot_svg_thumb.svg',
                     '../_images/sphx_glr_plot_numpy_matplotlib_thumb.png',
                     '../_images/sphx_glr_plot_animation_thumb.gif',
+                    '../_images/sphx_glr_plot_webp_thumb.webp',
                     ]
     for thumb_fname in thumb_fnames:
         file_fname = op.join(generated_examples_dir, thumb_fname)
         assert op.isfile(file_fname), file_fname
-        want_html = 'src="%s"' % (thumb_fname,)
+        want_html = f'src="{thumb_fname}"'
         assert want_html in html
     # the original GIF does not get copied because it's not used in the
-    # RST/HTML, so can't add it to this check
+    # reST/HTML, so can't add it to this check
     for ex, ext, nums, extra in (
             ('plot_svg', 'svg', [1], None),
             ('plot_numpy_matplotlib', 'png', [1], None),
-            ('plot_animation', 'png', [1, 3], 'function Animation')):
+            ('plot_animation', 'png', [1, 3], 'function Animation'),
+            ('plot_webp', 'webp', [1], None)):
         html_fname = op.join(generated_examples_dir, '%s.html' % ex)
         with codecs.open(html_fname, 'r', 'utf-8') as fid:
             html = fid.read()
@@ -308,13 +310,14 @@ def test_image_formats(sphinx_app):
             img_fname0 = '../_images/sphx_glr_%s_%03d.%s' % (ex, num, ext)
             file_fname = op.join(generated_examples_dir, img_fname0)
             assert op.isfile(file_fname), file_fname
-            want_html = 'src="%s"' % (img_fname0,)
+            want_html = f'src="{img_fname0}"'
             assert want_html in html
             img_fname2 = ('../_images/sphx_glr_%s_%03d_2_00x.%s' %
                           (ex, num, ext))
             file_fname2 = op.join(generated_examples_dir, img_fname2)
-            want_html = 'srcset="%s, %s 2.00x"' % (img_fname0, img_fname2)
-            if ext in ('png', 'jpg', 'svg'):  # check 2.00x (tests directive)
+            want_html = f'srcset="{img_fname0}, {img_fname2} 2.00x"'
+            if ext in ('png', 'jpg', 'svg', 'webp'):
+                # check 2.00x (tests directive)
                 assert op.isfile(file_fname2), file_fname2
                 assert want_html in html
 
@@ -548,7 +551,7 @@ def test_rebuild(tmpdir_factory, sphinx_app):
     #
     status = sphinx_app._status.getvalue()
     lines = [line for line in status.split('\n') if 'removed' in line]
-    want = '.*%s added, 0 changed, 0 removed.*' % (N_RST,)
+    want = f'.*{N_RST} added, 0 changed, 0 removed.*'
     assert re.match(want, status, re.MULTILINE | re.DOTALL) is not None, lines
     want = '.*targets for 2 source files that are out of date$.*'
     lines = [line for line in status.split('\n') if 'out of date' in line]
@@ -655,7 +658,7 @@ def test_rebuild(tmpdir_factory, sphinx_app):
     # mtimes for backrefs (gh-394)
     _assert_mtimes(generated_backrefs_0, generated_backrefs_1)
 
-    # generated RST files
+    # generated reST files
     ignore = (
         # these two should almost always be different, but in case we
         # get extremely unlucky and have identical run times
@@ -771,7 +774,7 @@ def _rerun(how, src_dir, conf_dir, out_dir, toctrees_dir,
     # mtimes for backrefs (gh-394)
     _assert_mtimes(generated_backrefs_0, generated_backrefs_1)
 
-    # generated RST files
+    # generated reST files
     different = ('plot_numpy_matplotlib',)
     ignore = (
         # this one should almost always be different, but in case we
@@ -1062,3 +1065,22 @@ def test_no_dummy_image(sphinx_app):
                    'sphx_glr_plot_repr_002.png')
     assert not op.isfile(img1)
     assert not op.isfile(img2)
+
+
+def test_jupyterlite_modifications(sphinx_app):
+    src_dir = sphinx_app.srcdir
+    jupyterlite_notebook_pattern = op.join(
+        src_dir, 'jupyterlite_contents', '**', '*.ipynb')
+    jupyterlite_notebook_filenames = glob.glob(
+        jupyterlite_notebook_pattern, recursive=True)
+
+    for notebook_filename in jupyterlite_notebook_filenames:
+        with open(notebook_filename) as f:
+            notebook_content = json.load(f)
+
+        first_cell = notebook_content['cells'][0]
+        assert first_cell['cell_type'] == 'markdown'
+        assert (
+            f"JupyterLite-specific change for {notebook_filename}"
+            in first_cell['source']
+        )
