@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 # Author: Óscar Nájera
 # License: 3-clause BSD
 r"""
 Testing the Jupyter notebook parser
 """
 
-from __future__ import division, absolute_import, print_function
 from collections import defaultdict
 from itertools import count
 import json
@@ -80,7 +78,7 @@ def test_code_conversion():
 
 
 def test_convert(gallery_conf):
-    """Test ReST conversion"""
+    """Test reST conversion"""
     rst = """hello
 
 .. contents::
@@ -272,7 +270,7 @@ def test_notebook_images_prefix(gallery_conf,
     """).format(rst_path)
     markdown = rst2md(rst, gallery_conf, target_dir, {})
 
-    assert 'src="{}"'.format(md_path) in markdown
+    assert f'src="{md_path}"' in markdown
     assert 'alt="My Image"' in markdown
     assert 'width="100px"' in markdown
     assert 'height="200px"' in markdown
@@ -327,11 +325,10 @@ def test_jupyter_notebook(gallery_conf):
     with tempfile.NamedTemporaryFile('w', delete=False) as f:
         save_notebook(example_nb, f.name)
     try:
-        with open(f.name, "r") as fname:
+        with open(f.name) as fname:
             assert json.load(fname) == example_nb
     finally:
         os.remove(f.name)
-    assert example_nb.get('cells')[0]['source'][0] == "%matplotlib inline"
 
     # Test custom first cell text
     test_text = '# testing\n%matplotlib notebook'
